@@ -21,7 +21,7 @@
 #' @importFrom DeclareDesign declare_estimand declare_estimator declare_population declare_sampling
 #' @importFrom fabricatr fabricate add_level draw_normal_icc draw_ordered
 #' @importFrom randomizr conduct_ra draw_rs 
-#' @importFrom estimatr tidy lm_robust
+#' @importFrom estimatr lm_robust
 #' @importFrom stats qnorm
 #' @export
 #' @examples
@@ -39,7 +39,7 @@ cluster_sampling_designer <- function(N_blocks = 1,
                                       n_i_in_cluster = 10,
                                       icc = 0.2
 ){
-  if(n_clusters_in_block > min(N_clusters_in_block)) stop(paste0("N_clusters_in_block sampled must be smaller than the total number of ", N_clusters_in_block, " clusters."))
+  if(n_clusters_in_block > min(N_clusters_in_block)) stop(paste0("n_clusters_in_block sampled must be smaller than the total number of ", N_clusters_in_block, " clusters."))
   if(n_i_in_cluster > min(N_i_in_cluster)) stop(paste0("n_i_in_cluster must be smaller than or equal to the minimum of ", N_i_in_cluster, " subjects per cluster."))
   if(icc < 0 || icc > 1) stop("icc must be a number in [0,1]")
   {{{
